@@ -1,11 +1,12 @@
 use Renard::Incunabula::Common::Setup;
 package Renard::Curie::Component::Outline;
 # ABSTRACT: Component that provides a list of headings for navigating
-$Renard::Curie::Component::Outline::VERSION = '0.003';
+$Renard::Curie::Component::Outline::VERSION = '0.004';
 use Moo;
 use Renard::Incunabula::Frontend::Gtk3::Helper;
 use Glib 'TRUE', 'FALSE';
-use Renard::Incunabula::Common::Types qw(InstanceOf PageNumber);
+use Renard::Incunabula::Common::Types qw(InstanceOf);
+use Renard::Incunabula::Document::Types qw(PageNumber);
 
 has _gtk_widget => (
 	is => 'lazy',
@@ -103,7 +104,7 @@ Renard::Curie::Component::Outline - Component that provides a list of headings f
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 EXTENDS
 
