@@ -1,9 +1,10 @@
 use Modern::Perl;
 package Renard::Curie::Error;
-# ABSTRACT: Exceptions
-$Renard::Curie::Error::VERSION = '0.002';
+# ABSTRACT: Exceptions for Curie
+$Renard::Curie::Error::VERSION = '0.004';
 use custom::failures qw/
-	IO::FileNotFound
+	User::InvalidPageNumber
+	ViewOptions::InvalidGridOptions
 	/;
 
 1;
@@ -16,11 +17,11 @@ __END__
 
 =head1 NAME
 
-Renard::Curie::Error - Exceptions
+Renard::Curie::Error - Exceptions for Curie
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 EXTENDS
 
@@ -28,6 +29,8 @@ version 0.002
 
 =item * L<failure>
 
+=item * L<failure>
+
 =back
 
 =head1 AUTHOR
